.. mdinclude:: ../README.md

Tables of contents and indices
------------------------------

.. toctree::
    :maxdepth: 4

    install
    tutorial
    api_py
    license
    changelog

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
